Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1610)

Unified Diff: chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc
diff --git a/chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc b/chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc
index 99a8b0763eadb9ce24fdf5bbb9f438f9d4d2f6e5..ec58792b5955d22a4ca33320776e333fbf8b3126 100644
--- a/chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc
+++ b/chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.cc
@@ -8,7 +8,7 @@
#include "ash/multi_profile_uma.h"
#include "ash/public/cpp/shell_window_ids.h"
#include "ash/shell.h"
-#include "ash/wm/maximize_mode/maximize_mode_controller.h"
+#include "ash/wm/tablet_mode/tablet_mode_controller.h"
#include "ash/wm/window_state.h"
#include "ash/wm_window.h"
#include "base/auto_reset.h"
@@ -683,12 +683,12 @@ void MultiUserWindowManagerChromeOS::SetWindowVisible(
aura::Window* window,
bool visible,
int animation_time_in_ms) {
// The MaximizeModeWindowManager will not handle invisible windows since they
// are not user activatable. Since invisible windows are not being tracked,
// we tell it to maximize / track this window now before it gets shown, to
// reduce animation jank from multiple resizes.
if (visible)
- ash::Shell::Get()->maximize_mode_controller()->AddWindow(window);
+ ash::Shell::Get()->tablet_mode_controller()->AddWindow(window);
AnimationSetter animation_setter(
window,
@@ -683,12 +683,12 @@ void MultiUserWindowManagerChromeOS::SetWindowVisible(
bool visible,
int animation_time_in_ms) {
- // The MaximizeModeWindowManager will not handle invisible windows since they
+ // The TabletModeWindowManager will not handle invisible windows since they
// are not user activatable. Since invisible windows are not being tracked,
// we tell it to maximize / track this window now before it gets shown, to

Powered by Google App Engine
This is Rietveld 408576698